@@ -2,6 +2,7 @@ from django.http import HttpResponse
 from django.core.management import call_command
 import requests
 import os
+from django.conf import settings
 
 def get_data(request):
     ws_url = os.getenv('LOCAL_IP', '')
@@ -24,6 +25,6 @@ def get_data(request):
 
     # os.system('rm -rf /var/www/html/gnp_covid_survey')
 
-    print(BASE_DIR)
+    print(settings.BASE_DIR)
 
     return HttpResponse(status=200)
\ No newline at end of file
